-- Imports the anim8 library and creates the local variables player_sprite and animation.
local anim8 = require 'anim8'
local player_sprite, animation 

objects = {} -- table to hold all our physical objects

function love.load()
    --Creates the Player variable which assigns a grid to the player sprite
	player = {
	    grid_x = 16,
        grid_y = 32,
		act_x = 2,
		act_y = 2,
	    speed = 10
	}
	--Adds Player Image to LOVE Engine
	player_sprite = love.graphics.newImage("Images/player/player_stacy.png")
    
	--Creates a starting animation based off of the Player Image
	g = anim8.newGrid(16, 32, player_sprite:getWidth(), player_sprite:getHeight())
	animation = anim8.newAnimation('loop', g('2,3'), 0.6)
	
	--Creates a Sky Blue Background and a Window that is 650 x 650 with no antialiasing or full screen and vsynch on.
	background = love.graphics.setBackgroundColor ( 158, 213, 228)
    resolution = love.graphics.setMode(650, 650, false, true, 0)
	
	--Creates a Physics World
	love.physics.setMeter(64)
	world = love.physics.newWorld(0, 9.81*64, true) -- Creates a world with the width of 650 and the height of 50
	
	--Creates Ground Object
	objects.ground = {}
	objects.ground.body = love.physics.newBody(world, 650/2, 650-50/2)
	objects.ground.shape = love.physics.newRectangleShape(650, 50)
	objects.ground.fixture = love.physics.newFixture(objects.ground.body, objects.ground.shape)
	
	
	-- Creates Physics for Player
	objects.player = {}
	objects.player.body = love.physics.newBody(world, 650/2, 650/2, "dynamic")
	objects.player.shape = love.physics.newRectangleShape (16, 32)
	objects.player.fixture = love.physics.newFixture(objects.player.body, objects.player.shape, 1)
	objects.player.fixture:setRestitution(0)
	
	-- Creates Physics
	 
	 
	-- Adds the Forest Theme
	music = love.audio.newSource("Music/Forest/Tea Roots.mp3")
	love.audio.play(music)
end


function love.keypressed(key)
    --Assigns the left key with animation and motion
	if key == "left" then
       player.grid_x = player.grid_x - 16 --Motion
	   animation = anim8.newAnimation('loop', g('1-2,2'), 0.6) -- Animation
	
	-- Same as above, except for the right key
	elseif key == "right" then
       player.grid_x = player.grid_x + 16
       animation = anim8.newAnimation('loop', g('1-2,1'), 0.6)
	end
end


function love.update(dt)
    --Does a mathmatical calculation that determines the players motion. Also updates animation.
	player.act_y = player.act_y - ((player.act_y - player.grid_y) * player.speed * dt)
    player.act_x = player.act_x - ((player.act_x - player.grid_x) * player.speed * dt)

	animation:update(dt)
	world:update(dt)
end


function love.draw()
    -- Draws the player image.
	love.graphics.setColor(255, 255, 255)
	animation:draw(player_sprite, player.act_x, player.act_y, objects.player.body:getX(), objects.player.body:getY())
	end